import { BasicColumn,FormSchema } from '/@/components/Table';
import { optionTypeListApi } from '/@/api/tigerapi/wms/materialreq';
import { optionsListApi } from '/@/api/tigerapi/wms/wms_item';
import { h,unref } from 'vue';
import { Tag, Tooltip } from 'ant-design-vue';
import { useI18n } from '/@/hooks/web/useI18n';
import{ useLocale } from '/@/locales/useLocale';
import { isNullOrEmpty } from '/@/utils/is';
const { t:bt } = useI18n();
const { getLocale }=useLocale();

export const columns: BasicColumn[] = [
  {
    title: bt('单据代码'),
    dataIndex: 'BILLCODE',
    width: 200,
    sorter:true,
    resizable:true
  },
  {
    title: bt('单据日期'),
    dataIndex: 'BILLDATE',
    width: 180,
    resizable:true
  },
  {
    title: bt('创建时间'),
    dataIndex: 'CREATE_TIME',
    width: 180,
    sorter:true,
    resizable:true
  },
  {
    title: bt('操作时间'),
    dataIndex: 'UPDATE_TIME',
    width: 180,
    sorter:true,
    resizable:true
  },
  {
    title: bt('T100单据代码'),
    dataIndex: 'ERP_BILL_CODE',
    width: 180,
    sorter:true,
    resizable:true
  },
  {
    title: bt('单据类型'),
    dataIndex: 'BIZTYPE',
    width: 180,
    sorter:true,
    resizable:true,
    customRender: ({ record }) => {
      const status = record.BIZTYPE;
      var text = '';
      var color = '';
      switch (status) {
        case '0':
          text = bt('自制');
          color = 'green';
          break;
        case '1':
          text = bt('委外');
          color = 'blue';
          break;
        // case '99':
        //   text = '其他';
        //   color = '#C2C247';
        //   break;
        default:
          break;
      }
      return h(Tooltip, { title: 'xxxxxx' }, () => h(Tag, { color: color }, () => text));
    },
  },
  {
    title: bt('ERP提示信息'),
    dataIndex: 'COMMIT_MSG',
    width: 180,
    sorter:true,
    resizable:true
  },
  {
    title: bt('ERP状态'),
    dataIndex: 'ERP_BILL_CODE',
    width: 180,
    sorter:true,
    resizable:true,
    customRender: ({ record }) => {
      const status = record.ERP_BILL_CODE;
      var text = '';
      var color='';
      if(isNullOrEmpty(status)){
        text = '未完成'
        color= 'red'
      }else{
        text = '完成'
        color= 'green'
      }
      return h(Tooltip, { title: status }, () => h(Tag,{ color: color }, () => text ));
    },
  },
  {
    title: bt('状态'),
    dataIndex: 'STATUS',
    width: 180,
    sorter:true,
    resizable:true,
    customRender: ({ record }) => {
      console.log('record', record);
      const status = record.STATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = bt('初始化');
          color = 'blue';
          break;
        case 1:
          text = bt('清点中');
          color = '#C2C247';
          break;
        case 2:
          text = bt('作业中');
          color = '#C2C247';
          break;
        case 3:
          text = bt('超发');
          color = 'green';
          break;
        case 4:
          text = bt('完成');
          color = 'green';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  
  {
    title: bt('仓库名称'),
    dataIndex: 'WAREHOUSECODE',
    width: 180,
    sorter:true,
    resizable:true
  },
  {
    title: bt('创建人'),
    dataIndex: 'CREATE_USER',
    width: 180,
    resizable:true
  },
];
//搜索
export const searchFormSchema: FormSchema[] = [
  {
    field: 'BILLCODE',
    label: bt('单据代码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'BILLDATE',
    label: bt('单据日期'),
    colProps: { span: 8 },
    component: 'RangePicker',
  },
  {
    field: 'STATUS',
    label: bt('状态'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: unref(getLocale)=='zh_CN'?'Desc':'Name',
      valueField: 'Value',
    },
  },
  {
    field: 'BIZTYPE',
    label: bt('单据类型'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionTypeListApi,
      resultField: 'Data',
      labelField: unref(getLocale)=='zh_CN'?'Desc':'Name',
      valueField: 'Value',
    },
  },
  {
    field: 'UPDATE_TIME',
    label: bt('操作时间'),
    colProps: { span: 8 },
    component: 'RangePicker',
  },
];

//领料单(WMS)明细
export const columns_D: BasicColumn[] = [

  {
    title: bt('组织机构授权标识字段'),
    dataIndex: 'AUTH_ORG',
    width: 200,
    ifShow: false
  },
  {
    title: bt('生产单元授权标识字段'),
    dataIndex: 'AUTH_PROD',
    width: 200,
    ifShow: false
  },
  {
    title: bt('仓库单元授权标识字段'),
    dataIndex: 'AUTH_WH',
    width: 200,
    ifShow: false
  },
  {
    title: bt('序号'),
    dataIndex: 'BILLLINE',
    width: 100,
    resizable:true
  },
  {
    title: bt('料号'),
    dataIndex: 'ITEM_CODE',
    width: 200,
    sorter:true,
    resizable:true
  },
  {
    title: bt('物料描述'),
    dataIndex: 'ITEM_NAME',
    width: 200,
    sorter:true,
    resizable:true
  },
  {
    title: bt('状态'),
    dataIndex: 'LINESTATUS',
    width: 180,
    sorter:true,
    resizable:true,
    customRender: ({ record }) => {
      console.log('record', record);
      const status = record.LINESTATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = bt('初始化');
          color = 'blue';
          break;
        case 1:
          text = bt('清点中');
          color = '#C2C247';
          break;
        case 2:
          text = bt('作业中');
          color = '#C2C247';
          break;
        case 3:
          text = bt('超发');
          color = 'green';
          break;
        case 4:
          text = bt('完成');
          color = 'green';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: bt('操作时间'),
    dataIndex: 'UPDATE_TIME',
    width: 180,
    sorter:true,
    resizable:true
  },
  {
    title: bt('仓库'),
    dataIndex: 'WAREHOUSECODE',
    width: 100,
    sorter:true,
    resizable:true
  },
  // {
  //   title: bt('旧料号'),
  //   dataIndex: 'WAREHOUSECODE',
  //   width: 180,
  // },
  {
    title: bt('需求数量'),
    dataIndex: 'PRQTY',
    width: 100,
    sorter:true,
    resizable:true
  },{
    title: bt('已发数量'),
    dataIndex: 'QTY',
    width: 100,
    sorter:true,
    resizable:true
  },
  {
    title: bt('欠发数量'),
    dataIndex: 'OWE_QTY',
    width: 100,
    sorter:true,
    resizable:true
  },
]

export const columns_S: BasicColumn[] = [
  {
    title: bt('组织机构授权标识字段'),
    dataIndex: 'AUTH_ORG',
    width: 200,
    ifShow: false
  },
  {
    title: bt('生产单元授权标识字段'),
    dataIndex: 'AUTH_PROD',
    width: 200,
    ifShow: false
  },
  {
    title: bt('仓库单元授权标识字段'),
    dataIndex: 'AUTH_WH',
    width: 200,
    ifShow: false
  },
  {
    title: bt('条码'),
    dataIndex: 'SN',
    width: 200,
    sorter:true,
    resizable:true
  },
  // {
  //   title: bt('创建时间'),
  //   dataIndex: 'CREATE_TIME',
  //   width: 180,
  //   sorter:true,
  // },
  {
    title: bt('修改时间'),
    dataIndex: 'UPDATE_TIME',
    width: 180,
    sorter:true,
    resizable:true
  },
  // {
  //   title: bt('单据类型'),
  //   dataIndex: 'BIZTYPE',
  //   width: 180,
  //   customRender: ({ record }) => {
  //     const status = record.BIZTYPE;
  //     var text = '';
  //     var color = '';
  //     switch (status) {
  //       case '1':
  //         text = bt('采购');
  //         color = 'green';
  //         break;
  //       case '2':
  //         text = bt('委外');
  //         color = 'blue';
  //         break;
  //       // case '99':
  //       //   text = '其他';
  //       //   color = '#C2C247';
  //       //   break;
  //       default:
  //         break;
  //     }
  //     return h(Tooltip, { title: 'xxxxxx' }, () => h(Tag, { color: color }, () => text));
  //   },
  // },
  {
    title: bt('状态'),
    dataIndex: 'STATUS',
    width: 180,
    sorter:true,
    resizable:true,
    customRender: ({ record }) => {
      console.log('record', record);
      const status = record.STATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = '不存在';
          color = 'green';
          break;
        case 10:
          text = '送货中';
          color = 'blue';
          break;
        case 20:
          text = '待检验';
          color = 'green';
          break;
        case 30:
          text = '待入库';
          color = '#C2C247';
          break;
        case 40:
          text = '在库中';
          color = 'blue';
          break;
        case 50:
          text = '已下架';
          color = 'green';
          break;
        case 60:
          text = '已发料';
          color = 'red';
          break;
        case 70:
          text = '已上料';
          color = 'red';
          break;
        case 80:
          text = '已耗尽';
          color = 'green';
          break;
        case 90:
          text = '已退料';
          color = 'green';
          break;
        case 100:
          text = '已发货';
          color = 'green';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: bt('物料编码'),
    dataIndex: 'ITEM_CODE',
    width: 200,
    sorter:true,
    resizable:true
  },
  {
    title: bt('库存数量'),
    dataIndex: 'QTY',
    width: 200,
    sorter:true,
    resizable:true
  },
  {
    title: bt('发料数量'),
    dataIndex: 'ALLOC_QTY',
    width: 200,
    sorter:true,
    resizable:true
  },
];

export const searchFormSchema_D: FormSchema[] = [
  {
    field: 'ITEM_CODE',
    label: bt('物料编码'),
    colProps: { span: 8 },
    component: 'Input',
  }
];
export const searchFormSchema_S: FormSchema[] = [
  // {
  //   field: 'BILLCODE',
  //   label: bt('单据代码'),
  //   colProps: { span: 8 },
  //   component: 'Input',
  // },
  {
    field: 'ITEM_CODE',
    label: bt('物料编码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'SN',
    label: bt('条码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'LINESTATUS',
    label: bt('状态'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
    },
  },
  // {
  //   field: 'BIZTYPE',
  //   label: bt('单据类型'),
  //   component: 'ApiSelect',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     api: optionTypeListApi,
  //     resultField: 'Data',
  //     labelField: unref(getLocale)=='zh_CN'?'Desc':'Name',
  //     valueField: 'Value',
  //   },
  // },
];

